==> libreoffice-4.1.5.3.tar.xz: libreoffice-4.1.5.3/svx/source/stbctrls/stbctrls.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef _SVX_STBCTRLS_H
#define _SVX_STBCTRLS_H

// defines ------------------------------------------------------------------

#define ZOOM_200            1
#define ZOOM_150            2
#define ZOOM_100            3
#define ZOOM_75             4
#define ZOOM_50             5

#define ZOOM_OPTIMAL        6
#define ZOOM_PAGE_WIDTH     7
#define ZOOM_WHOLE_PAGE     8

// IDs as in SUBTOTAL_FUNC of Calc

#define PSZ_FUNC_AVG                1
#define PSZ_FUNC_COUNT2             3
#define PSZ_FUNC_COUNT              2
#define PSZ_FUNC_MAX                4
#define PSZ_FUNC_MIN                5
#define PSZ_FUNC_SUM                9
#define PSZ_FUNC_SELECTION_COUNT    12
#define PSZ_FUNC_NONE               16

#define XMLSEC_CALL         1

#define SELECTION_STANDARD  1
#define SELECTION_EXTENDED  2
#define SELECTION_ADDED     3
#define SELECTION_BLOCK     4

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-5.1.3.2.tar.xz: libreoffice-5.1.3.2/svx/source/stbctrls/stbctrls.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */
#ifndef INCLUDED_SVX_SOURCE_STBCTRLS_STBCTRLS_H
#define INCLUDED_SVX_SOURCE_STBCTRLS_STBCTRLS_H

#define ZOOM_200            1
#define ZOOM_150            2
#define ZOOM_100            3
#define ZOOM_75             4
#define ZOOM_50             5

#define ZOOM_OPTIMAL        6
#define ZOOM_PAGE_WIDTH     7
#define ZOOM_WHOLE_PAGE     8

// IDs as in SUBTOTAL_FUNC of Calc

#define PSZ_FUNC_AVG                1
#define PSZ_FUNC_COUNT2             3
#define PSZ_FUNC_COUNT              2
#define PSZ_FUNC_MAX                4
#define PSZ_FUNC_MIN                5
#define PSZ_FUNC_SUM                9
#define PSZ_FUNC_SELECTION_COUNT    12
#define PSZ_FUNC_NONE               16

#define XMLSEC_CALL         1

#define SELECTION_STANDARD  1
#define SELECTION_EXTENDED  2
#define SELECTION_ADDED     3
#define SELECTION_BLOCK     4

#endif

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
